@@ -180,7 +180,23 @@ class CfnEnvironmentEC2(
         :param tags: An array of key-value pairs that will be associated with the new AWS Cloud9 development environment.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(CfnEnvironmentEC2.__init__)
+            def stub(
+                scope: aws_cdk.core.Construct,
+                id: builtins.str,
+                *,
+                instance_type: builtins.str,
+                automatic_stop_time_minutes: typing.Optional[jsii.Number] = None,
+                connection_type: typing.Optional[builtins.str] = None,
+                description: typing.Optional[builtins.str] = None,
+                image_id: typing.Optional[builtins.str] = None,
+                name: typing.Optional[builtins.str] = None,
+                owner_arn: typing.Optional[builtins.str] = None,
+                repositories: typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.Sequence[typing.Union[typing.Union["CfnEnvironmentEC2.RepositoryProperty", typing.Dict[str, typing.Any]], aws_cdk.core.IResolvable]]]] = None,
+                subnet_id: typing.Optional[builtins.str] = None,
+                tags: typing.Optional[typing.Sequence[typing.Union[aws_cdk.core.CfnTag, typing.Dict[str, typing.Any]]]] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = CfnEnvironmentEC2Props(
@@ -205,7 +221,9 @@ class CfnEnvironmentEC2(
         :param inspector: - tree inspector to collect and process attributes.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(CfnEnvironmentEC2.inspect)
+            def stub(inspector: aws_cdk.core.TreeInspector) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument inspector", value=inspector, expected_type=type_hints["inspector"])
         return typing.cast(None, jsii.invoke(self, "inspect", [inspector]))
 
@@ -218,7 +236,9 @@ class CfnEnvironmentEC2(
         :param props: -
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(CfnEnvironmentEC2._render_properties)
+            def stub(props: typing.Mapping[builtins.str, typing.Any]) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument props", value=props, expected_type=type_hints["props"])
         return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "renderProperties", [props]))
 
@@ -272,7 +292,9 @@ class CfnEnvironmentEC2(
     @instance_type.setter
     def instance_type(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(CfnEnvironmentEC2, "instance_type").fset)
+            def stub(value: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "instanceType", value)
 
@@ -288,7 +310,9 @@ class CfnEnvironmentEC2(
     @automatic_stop_time_minutes.setter
     def automatic_stop_time_minutes(self, value: typing.Optional[jsii.Number]) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(CfnEnvironmentEC2, "automatic_stop_time_minutes").fset)
+            def stub(value: typing.Optional[jsii.Number]) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "automaticStopTimeMinutes", value)
 
@@ -306,7 +330,9 @@ class CfnEnvironmentEC2(
     @connection_type.setter
     def connection_type(self, value: typing.Optional[builtins.str]) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(CfnEnvironmentEC2, "connection_type").fset)
+            def stub(value: typing.Optional[builtins.str]) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "connectionType", value)
 
@@ -322,7 +348,9 @@ class CfnEnvironmentEC2(
     @description.setter
     def description(self, value: typing.Optional[builtins.str]) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(CfnEnvironmentEC2, "description").fset)
+            def stub(value: typing.Optional[builtins.str]) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "description", value)
 
@@ -354,7 +382,9 @@ class CfnEnvironmentEC2(
     @image_id.setter
     def image_id(self, value: typing.Optional[builtins.str]) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(CfnEnvironmentEC2, "image_id").fset)
+            def stub(value: typing.Optional[builtins.str]) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "imageId", value)
 
@@ -370,7 +400,9 @@ class CfnEnvironmentEC2(
     @name.setter
     def name(self, value: typing.Optional[builtins.str]) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(CfnEnvironmentEC2, "name").fset)
+            def stub(value: typing.Optional[builtins.str]) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "name", value)
 
@@ -388,7 +420,9 @@ class CfnEnvironmentEC2(
     @owner_arn.setter
     def owner_arn(self, value: typing.Optional[builtins.str]) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(CfnEnvironmentEC2, "owner_arn").fset)
+            def stub(value: typing.Optional[builtins.str]) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "ownerArn", value)
 
@@ -409,7 +443,11 @@ class CfnEnvironmentEC2(
         value: typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union["CfnEnvironmentEC2.RepositoryProperty", aws_cdk.core.IResolvable]]]],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(CfnEnvironmentEC2, "repositories").fset)
+            def stub(
+                value: typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union["CfnEnvironmentEC2.RepositoryProperty", aws_cdk.core.IResolvable]]]],
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "repositories", value)
 
@@ -425,7 +463,9 @@ class CfnEnvironmentEC2(
     @subnet_id.setter
     def subnet_id(self, value: typing.Optional[builtins.str]) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(CfnEnvironmentEC2, "subnet_id").fset)
+            def stub(value: typing.Optional[builtins.str]) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "subnetId", value)
 
@@ -464,7 +504,13 @@ class CfnEnvironmentEC2(
                 )
             '''
             if __debug__:
-                type_hints = typing.get_type_hints(CfnEnvironmentEC2.RepositoryProperty.__init__)
+                def stub(
+                    *,
+                    path_component: builtins.str,
+                    repository_url: builtins.str,
+                ) -> None:
+                    ...
+                type_hints = typing.get_type_hints(stub)
                 check_type(argname="argument path_component", value=path_component, expected_type=type_hints["path_component"])
                 check_type(argname="argument repository_url", value=repository_url, expected_type=type_hints["repository_url"])
             self._values: typing.Dict[str, typing.Any] = {
@@ -583,7 +629,21 @@ class CfnEnvironmentEC2Props:
             )
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(CfnEnvironmentEC2Props.__init__)
+            def stub(
+                *,
+                instance_type: builtins.str,
+                automatic_stop_time_minutes: typing.Optional[jsii.Number] = None,
+                connection_type: typing.Optional[builtins.str] = None,
+                description: typing.Optional[builtins.str] = None,
+                image_id: typing.Optional[builtins.str] = None,
+                name: typing.Optional[builtins.str] = None,
+                owner_arn: typing.Optional[builtins.str] = None,
+                repositories: typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.Sequence[typing.Union[typing.Union[CfnEnvironmentEC2.RepositoryProperty, typing.Dict[str, typing.Any]], aws_cdk.core.IResolvable]]]] = None,
+                subnet_id: typing.Optional[builtins.str] = None,
+                tags: typing.Optional[typing.Sequence[typing.Union[aws_cdk.core.CfnTag, typing.Dict[str, typing.Any]]]] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument instance_type", value=instance_type, expected_type=type_hints["instance_type"])
             check_type(argname="argument automatic_stop_time_minutes", value=automatic_stop_time_minutes, expected_type=type_hints["automatic_stop_time_minutes"])
             check_type(argname="argument connection_type", value=connection_type, expected_type=type_hints["connection_type"])
@@ -789,7 +849,12 @@ class CloneRepository(
         :stability: experimental
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(CloneRepository.from_code_commit)
+            def stub(
+                repository: aws_cdk.aws_codecommit.IRepository,
+                path: builtins.str,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument repository", value=repository, expected_type=type_hints["repository"])
             check_type(argname="argument path", value=path, expected_type=type_hints["path"])
         return typing.cast("CloneRepository", jsii.sinvoke(cls, "fromCodeCommit", [repository, path]))
@@ -895,7 +960,18 @@ class Ec2EnvironmentProps:
         if isinstance(subnet_selection, dict):
             subnet_selection = aws_cdk.aws_ec2.SubnetSelection(**subnet_selection)
         if __debug__:
-            type_hints = typing.get_type_hints(Ec2EnvironmentProps.__init__)
+            def stub(
+                *,
+                vpc: aws_cdk.aws_ec2.IVpc,
+                cloned_repositories: typing.Optional[typing.Sequence[CloneRepository]] = None,
+                connection_type: typing.Optional[ConnectionType] = None,
+                description: typing.Optional[builtins.str] = None,
+                ec2_environment_name: typing.Optional[builtins.str] = None,
+                instance_type: typing.Optional[aws_cdk.aws_ec2.InstanceType] = None,
+                subnet_selection: typing.Optional[typing.Union[aws_cdk.aws_ec2.SubnetSelection, typing.Dict[str, typing.Any]]] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument vpc", value=vpc, expected_type=type_hints["vpc"])
             check_type(argname="argument cloned_repositories", value=cloned_repositories, expected_type=type_hints["cloned_repositories"])
             check_type(argname="argument connection_type", value=connection_type, expected_type=type_hints["connection_type"])
@@ -1135,7 +1211,20 @@ class Ec2Environment(
         :stability: experimental
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(Ec2Environment.__init__)
+            def stub(
+                scope: constructs.Construct,
+                id: builtins.str,
+                *,
+                vpc: aws_cdk.aws_ec2.IVpc,
+                cloned_repositories: typing.Optional[typing.Sequence[CloneRepository]] = None,
+                connection_type: typing.Optional[ConnectionType] = None,
+                description: typing.Optional[builtins.str] = None,
+                ec2_environment_name: typing.Optional[builtins.str] = None,
+                instance_type: typing.Optional[aws_cdk.aws_ec2.InstanceType] = None,
+                subnet_selection: typing.Optional[typing.Union[aws_cdk.aws_ec2.SubnetSelection, typing.Dict[str, typing.Any]]] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = Ec2EnvironmentProps(
@@ -1167,7 +1256,13 @@ class Ec2Environment(
         :stability: experimental
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(Ec2Environment.from_ec2_environment_name)
+            def stub(
+                scope: constructs.Construct,
+                id: builtins.str,
+                ec2_environment_name: builtins.str,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
             check_type(argname="argument ec2_environment_name", value=ec2_environment_name, expected_type=type_hints["ec2_environment_name"])
